@@ -6,15 +6,9 @@
 
 #include "autocorrection_gui.h"
 #include <PimCommon/LineEditWithAutoCorrection>
-#if HAVE_TEXT_AUTOCORRECTION_WIDGETS
 #include <TextAutoCorrectionCore/AutoCorrection>
 #include <TextAutoCorrectionWidgets/AutoCorrectionWidget>
 #include <textautocorrectioncore/textautocorrectionsettings.h>
-#else
-#include <TextAutoCorrection/AutoCorrection>
-#include <TextAutoCorrection/AutoCorrectionWidget>
-#include <textautocorrection/textautocorrectionsettings.h>
-#endif
 
 #include <QAction>
 #include <QApplication>
@@ -25,11 +19,7 @@
 #include <QPushButton>
 #include <QToolBar>
 #include <QVBoxLayout>
-#if HAVE_TEXT_AUTOCORRECTION_WIDGETS
 ConfigureTestDialog::ConfigureTestDialog(TextAutoCorrectionCore::AutoCorrection *autoCorrection, QWidget *parent)
-#else
-ConfigureTestDialog::ConfigureTestDialog(TextAutoCorrection::AutoCorrection *autoCorrection, QWidget *parent)
-#endif
     : QDialog(parent)
 {
     setWindowTitle(QStringLiteral("Configure Autocorrection"));
@@ -42,11 +32,7 @@ ConfigureTestDialog::ConfigureTestDialog(TextAutoCorrection::AutoCorrection *aut
     connect(buttonBox, &QDialogButtonBox::rejected, this, &ConfigureTestDialog::reject);
 
     buttonBox->button(QDialogButtonBox::Ok)->setDefault(true);
-#if HAVE_TEXT_AUTOCORRECTION_WIDGETS
     mWidget = new TextAutoCorrectionWidgets::AutoCorrectionWidget(this);
-#else
-    mWidget = new TextAutoCorrection::AutoCorrectionWidget(this);
-#endif
     mainLayout->addWidget(mWidget);
     mainLayout->addWidget(buttonBox);
 
@@ -62,11 +48,7 @@ void ConfigureTestDialog::slotSaveSettings()
     mWidget->writeConfig();
 }
 
-#if HAVE_TEXT_AUTOCORRECTION_WIDGETS
 TextEditAutoCorrectionWidget::TextEditAutoCorrectionWidget(TextAutoCorrectionCore::AutoCorrection *autoCorrection, QWidget *parent)
-#else
-TextEditAutoCorrectionWidget::TextEditAutoCorrectionWidget(TextAutoCorrection::AutoCorrection *autoCorrection, QWidget *parent)
-#endif
     : QTextEdit(parent)
     , mAutoCorrection(autoCorrection)
 {
@@ -98,15 +80,9 @@ AutocorrectionTestWidget::AutocorrectionTestWidget(QWidget *parent)
     : QWidget(parent)
     , mConfig(KSharedConfig::openConfig(QStringLiteral("autocorrectionguirc")))
 {
-#if HAVE_TEXT_AUTOCORRECTION_WIDGETS
     TextAutoCorrectionCore::TextAutoCorrectionSettings::self()->setSharedConfig(mConfig);
     TextAutoCorrectionCore::TextAutoCorrectionSettings::self()->load();
     mAutoCorrection = new TextAutoCorrectionCore::AutoCorrection;
-#else
-    TextAutoCorrection::TextAutoCorrectionSettings::self()->setSharedConfig(mConfig);
-    TextAutoCorrection::TextAutoCorrectionSettings::self()->load();
-    mAutoCorrection = new TextAutoCorrection::AutoCorrection;
-#endif
 
     auto lay = new QVBoxLayout(this);
     auto bar = new QToolBar;
@@ -140,11 +116,7 @@ void AutocorrectionTestWidget::slotConfigure()
 {
     QPointer<ConfigureTestDialog> dlg = new ConfigureTestDialog(mAutoCorrection, this);
     if (dlg->exec()) {
-#if HAVE_TEXT_AUTOCORRECTION_WIDGETS
         TextAutoCorrectionCore::TextAutoCorrectionSettings::self()->save();
-#else
-        TextAutoCorrection::TextAutoCorrectionSettings::self()->save();
-#endif
     }
     delete dlg;
 }
@@ -166,3 +138,5 @@ int main(int argc, char **argv)
     delete w;
     return ret;
 }
+
+#include "moc_autocorrection_gui.cpp"
