@@ -11,9 +11,12 @@
 #include <QWidget>
 
 #include <QTextEdit>
-namespace TextAutoCorrection
+namespace TextAutoCorrectionCore
 {
 class AutoCorrection;
+}
+namespace TextAutoCorrectionWidgets
+{
 class AutoCorrectionWidget;
 }
 namespace PimCommon
@@ -24,28 +27,28 @@ class ConfigureTestDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit ConfigureTestDialog(TextAutoCorrection::AutoCorrection *autoCorrection, QWidget *parent = nullptr);
+    explicit ConfigureTestDialog(TextAutoCorrectionCore::AutoCorrection *autoCorrection, QWidget *parent = nullptr);
     ~ConfigureTestDialog() override;
 
 private Q_SLOTS:
     void slotSaveSettings();
 
 private:
-    TextAutoCorrection::AutoCorrectionWidget *mWidget = nullptr;
+    TextAutoCorrectionWidgets::AutoCorrectionWidget *mWidget = nullptr;
 };
 
 class TextEditAutoCorrectionWidget : public QTextEdit
 {
     Q_OBJECT
 public:
-    explicit TextEditAutoCorrectionWidget(TextAutoCorrection::AutoCorrection *autoCorrection, QWidget *parent = nullptr);
+    explicit TextEditAutoCorrectionWidget(TextAutoCorrectionCore::AutoCorrection *autoCorrection, QWidget *parent = nullptr);
     ~TextEditAutoCorrectionWidget() override;
 
 protected:
     void keyPressEvent(QKeyEvent *e) override;
 
 private:
-    TextAutoCorrection::AutoCorrection *mAutoCorrection = nullptr;
+    TextAutoCorrectionCore::AutoCorrection *mAutoCorrection = nullptr;
 };
 
 class AutocorrectionTestWidget : public QWidget
@@ -62,6 +65,6 @@ private Q_SLOTS:
 private:
     TextEditAutoCorrectionWidget *mEdit = nullptr;
     PimCommon::LineEditWithAutoCorrection *mSubject = nullptr;
-    TextAutoCorrection::AutoCorrection *mAutoCorrection = nullptr;
+    TextAutoCorrectionCore::AutoCorrection *mAutoCorrection = nullptr;
     KSharedConfig::Ptr mConfig;
 };
