@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,9 +19,7 @@ ConfigurePluginsWidgetTest::ConfigurePluginsWidgetTest(QObject *parent)
     QStandardPaths::setTestModeEnabled(true);
 }
 
-ConfigurePluginsWidgetTest::~ConfigurePluginsWidgetTest()
-{
-}
+ConfigurePluginsWidgetTest::~ConfigurePluginsWidgetTest() = default;
 
 void ConfigurePluginsWidgetTest::shouldHaveDefaultValue()
 {
@@ -46,3 +44,5 @@ void ConfigurePluginsWidgetTest::shouldHaveDefaultValue()
 }
 
 QTEST_MAIN(ConfigurePluginsWidgetTest)
+
+#include "moc_configurepluginswidgettest.cpp"
