@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,9 +11,7 @@ CustomToolsViewInterface::CustomToolsViewInterface(QWidget *parent)
 {
 }
 
-CustomToolsViewInterface::~CustomToolsViewInterface()
-{
-}
+CustomToolsViewInterface::~CustomToolsViewInterface() = default;
 
 void CustomToolsViewInterface::setText(const QString &)
 {
@@ -23,3 +21,5 @@ KToggleAction *CustomToolsViewInterface::action() const
 {
     return nullptr;
 }
+
+#include "moc_customtoolsviewinterface.cpp"
