@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,7 +9,6 @@
 #include "pimcommon_debug.h"
 
 #include <KPluginFactory>
-#include <KPluginLoader>
 
 #include <QFileInfo>
 
@@ -18,10 +17,9 @@ using namespace PimCommon;
 class GenericPluginInfo
 {
 public:
-    GenericPluginInfo()
-    {
-    }
+    GenericPluginInfo() = default;
 
+    KPluginMetaData data;
     QString metaDataFileNameBaseName;
     QString metaDataFileName;
     PimCommon::PluginUtilData pluginData;
@@ -40,25 +38,25 @@ QString pluginVersion()
 class PimCommon::GenericPluginManagerPrivate
 {
 public:
-    GenericPluginManagerPrivate(GenericPluginManager *qq)
+    explicit GenericPluginManagerPrivate(GenericPluginManager *qq)
         : q(qq)
     {
     }
 
     void loadPlugin(GenericPluginInfo *item);
-    QVector<GenericPlugin *> pluginsList() const;
+    [[nodiscard]] QList<GenericPlugin *> pluginsList() const;
     bool initializePlugins();
     QString pluginDirectory;
     QString pluginName;
-    QVector<GenericPluginInfo> mPluginList;
+    QList<GenericPluginInfo> mPluginList;
 
-    QVector<PluginUtilData> pluginsDataList() const;
-    QString configGroupName() const;
-    QString configPrefixSettingKey() const;
+    [[nodiscard]] QList<PluginUtilData> pluginsDataList() const;
+    [[nodiscard]] QString configGroupName() const;
+    [[nodiscard]] QString configPrefixSettingKey() const;
     GenericPlugin *pluginFromIdentifier(const QString &id);
 
 private:
-    QVector<PluginUtilData> mPluginDataList;
+    QList<PluginUtilData> mPluginDataList;
     GenericPluginManager *const q;
 };
 
@@ -81,10 +79,10 @@ bool GenericPluginManagerPrivate::initializePlugins()
     if (pluginDirectory.isEmpty() || pluginName.isEmpty()) {
         return false;
     }
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(pluginDirectory);
+    const QList<KPluginMetaData> plugins = KPluginMetaData::findPlugins(pluginDirectory);
 
     const QPair<QStringList, QStringList> pair = PimCommon::PluginUtil::loadPluginSetting(configGroupName(), configPrefixSettingKey());
-    QVectorIterator<KPluginMetaData> i(plugins);
+    QListIterator<KPluginMetaData> i(plugins);
     i.toBack();
     while (i.hasPrevious()) {
         GenericPluginInfo info;
@@ -98,6 +96,7 @@ bool GenericPluginManagerPrivate::initializePlugins()
         info.isEnabled = isPluginActivated;
         info.metaDataFileNameBaseName = QFileInfo(data.fileName()).baseName();
         info.metaDataFileName = data.fileName();
+        info.data = data;
 
         if (pluginVersion() == data.version()) {
             info.plugin = nullptr;
@@ -106,23 +105,23 @@ bool GenericPluginManagerPrivate::initializePlugins()
             qCWarning(PIMCOMMON_LOG) << "Plugin " << data.name() << " doesn't have correction plugin version. It will not be loaded.";
         }
     }
-    QVector<GenericPluginInfo>::iterator end(mPluginList.end());
-    for (QVector<GenericPluginInfo>::iterator it = mPluginList.begin(); it != end; ++it) {
+    QList<GenericPluginInfo>::iterator end(mPluginList.end());
+    for (QList<GenericPluginInfo>::iterator it = mPluginList.begin(); it != end; ++it) {
         loadPlugin(&(*it));
     }
     return true;
 }
 
-QVector<PluginUtilData> GenericPluginManagerPrivate::pluginsDataList() const
+QList<PluginUtilData> GenericPluginManagerPrivate::pluginsDataList() const
 {
     return mPluginDataList;
 }
 
-QVector<GenericPlugin *> GenericPluginManagerPrivate::pluginsList() const
+QList<GenericPlugin *> GenericPluginManagerPrivate::pluginsList() const
 {
-    QVector<PimCommon::GenericPlugin *> lst;
-    QVector<GenericPluginInfo>::ConstIterator end(mPluginList.constEnd());
-    for (QVector<GenericPluginInfo>::ConstIterator it = mPluginList.constBegin(); it != end; ++it) {
+    QList<PimCommon::GenericPlugin *> lst;
+    QList<GenericPluginInfo>::ConstIterator end(mPluginList.constEnd());
+    for (QList<GenericPluginInfo>::ConstIterator it = mPluginList.constBegin(); it != end; ++it) {
         if (auto plugin = (*it).plugin) {
             lst << plugin;
         }
@@ -132,9 +131,8 @@ QVector<GenericPlugin *> GenericPluginManagerPrivate::pluginsList() const
 
 void GenericPluginManagerPrivate::loadPlugin(GenericPluginInfo *item)
 {
-    KPluginLoader pluginLoader(item->metaDataFileName);
-    if (pluginLoader.factory()) {
-        item->plugin = pluginLoader.factory()->create<PimCommon::GenericPlugin>(q, QVariantList() << item->metaDataFileNameBaseName);
+    if (auto plugin = KPluginFactory::instantiatePlugin<PimCommon::GenericPlugin>(item->data, q, QVariantList() << item->metaDataFileNameBaseName).plugin) {
+        item->plugin = plugin;
         item->plugin->setIsEnabled(item->isEnabled);
         item->pluginData.mHasConfigureDialog = item->plugin->hasConfigureDialog();
         mPluginDataList.append(item->pluginData);
@@ -143,8 +141,8 @@ void GenericPluginManagerPrivate::loadPlugin(GenericPluginInfo *item)
 
 GenericPlugin *GenericPluginManagerPrivate::pluginFromIdentifier(const QString &id)
 {
-    QVector<GenericPluginInfo>::ConstIterator end(mPluginList.constEnd());
-    for (QVector<GenericPluginInfo>::ConstIterator it = mPluginList.constBegin(); it != end; ++it) {
+    QList<GenericPluginInfo>::ConstIterator end(mPluginList.constEnd());
+    for (QList<GenericPluginInfo>::ConstIterator it = mPluginList.constBegin(); it != end; ++it) {
         if ((*it).pluginData.mIdentifier == id) {
             return (*it).plugin;
         }
@@ -158,10 +156,7 @@ GenericPluginManager::GenericPluginManager(QObject *parent)
 {
 }
 
-GenericPluginManager::~GenericPluginManager()
-{
-    delete d;
-}
+GenericPluginManager::~GenericPluginManager() = default;
 
 bool GenericPluginManager::initializePlugins()
 {
@@ -188,12 +183,12 @@ QString GenericPluginManager::pluginName() const
     return d->pluginName;
 }
 
-QVector<GenericPlugin *> GenericPluginManager::pluginsList() const
+QList<GenericPlugin *> GenericPluginManager::pluginsList() const
 {
     return d->pluginsList();
 }
 
-QVector<PluginUtilData> GenericPluginManager::pluginsDataList() const
+QList<PluginUtilData> GenericPluginManager::pluginsDataList() const
 {
     return d->pluginsDataList();
 }
@@ -212,3 +207,5 @@ GenericPlugin *GenericPluginManager::pluginFromIdentifier(const QString &id)
 {
     return d->pluginFromIdentifier(id);
 }
+
+#include "moc_genericpluginmanager.cpp"
