@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -71,12 +71,12 @@ public:
 
     void slotRemove()
     {
-        const int answer = KMessageBox::questionYesNo(q,
-                                                      i18n("Do you want to delete selected template?"),
-                                                      i18n("Delete template"),
-                                                      KStandardGuiItem::del(),
-                                                      KStandardGuiItem::cancel());
-        if (answer == KMessageBox::Yes) {
+        const int answer = KMessageBox::questionTwoActions(q,
+                                                           i18n("Do you want to delete selected template?"),
+                                                           i18nc("@title:window", "Delete template"),
+                                                           KStandardGuiItem::del(),
+                                                           KStandardGuiItem::cancel());
+        if (answer == KMessageBox::ButtonCode::PrimaryAction) {
             const QList<QListWidgetItem *> lstSelectedItems = q->selectedItems();
             for (QListWidgetItem *item : lstSelectedItems) {
                 if (item->data(TemplateListWidget::DefaultTemplate).toBool() == false) {
@@ -213,11 +213,11 @@ public:
     void load()
     {
         q->clear();
-        const QVector<PimCommon::defaultTemplate> templatesLst = q->defaultTemplates();
+        const QList<PimCommon::defaultTemplate> templatesLst = q->defaultTemplates();
         for (const PimCommon::defaultTemplate &tmp : templatesLst) {
             createListWidgetItem(tmp.name, tmp.text, true);
         }
-        KConfigGroup group = config.data()->group("template");
+        KConfigGroup group = config.data()->group(QStringLiteral("template"));
         if (group.hasKey(QStringLiteral("templateCount"))) {
             loadTemplates(config.data());
         }
@@ -226,7 +226,7 @@ public:
 
     void loadTemplates(KConfig *configFile)
     {
-        KConfigGroup group = configFile->group("template");
+        KConfigGroup group = configFile->group(QStringLiteral("template"));
         if (group.hasKey(QStringLiteral("templateCount"))) {
             const int numberTemplate = group.readEntry("templateCount", 0);
             for (int i = 0; i < numberTemplate; ++i) {
@@ -258,7 +258,7 @@ public:
                 ++numberOfTemplate;
             }
         }
-        KConfigGroup group = configFile->group("template");
+        KConfigGroup group = configFile->group(QStringLiteral("template"));
         group.writeEntry("templateCount", numberOfTemplate);
         configFile->sync();
     }
@@ -304,7 +304,7 @@ void TemplateListWidget::loadTemplates()
     d->load();
 }
 
-QVector<defaultTemplate> TemplateListWidget::defaultTemplates()
+QList<defaultTemplate> TemplateListWidget::defaultTemplates()
 {
     return {};
 }
@@ -315,11 +315,7 @@ QStringList TemplateListWidget::mimeTypes() const
     return lst;
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-QMimeData *TemplateListWidget::mimeData(const QList<QListWidgetItem *> items) const
-#else
 QMimeData *TemplateListWidget::mimeData(const QList<QListWidgetItem *> &items) const
-#endif
 {
     if (items.isEmpty()) {
         return nullptr;
@@ -384,3 +380,5 @@ void TemplateListWidget::addDefaultTemplate(const QString &templateName, const Q
     d->createListWidgetItem(templateName, templateScript, true);
 }
 }
+
+#include "moc_templatelistwidget.cpp"
