@@ -16,7 +16,7 @@ class TemplateListWidget;
 struct TemplateInfo {
     QString name;
     QString script;
-    Q_REQUIRED_RESULT bool isValid() const
+    [[nodiscard]] bool isValid() const
     {
         return !name.isEmpty() && !script.isEmpty();
     }
@@ -36,10 +36,10 @@ public:
     ~TemplateManager() override;
 
 private:
-    void slotDirectoryChanged();
-    void loadTemplates(bool init = false);
-    void initTemplatesDirectories(const QString &templatesRelativePath);
-    TemplateInfo loadTemplate(const QString &themePath, const QString &defaultDesktopFileName);
+    PIMCOMMON_NO_EXPORT void slotDirectoryChanged();
+    PIMCOMMON_NO_EXPORT void loadTemplates(bool init = false);
+    PIMCOMMON_NO_EXPORT void initTemplatesDirectories(const QString &templatesRelativePath);
+    [[nodiscard]] PIMCOMMON_NO_EXPORT TemplateInfo loadTemplate(const QString &themePath, const QString &defaultDesktopFileName);
 
     std::unique_ptr<TemplateManagerPrivate> const d;
 };
