@@ -10,7 +10,6 @@
 #include <QPainter>
 #include <QTextDocument>
 
-#include "pimcommon_debug.h"
 using namespace PimCommon;
 
 LogItemDelegate::LogItemDelegate(QObject *parent)
@@ -183,3 +182,5 @@ bool CustomLogWidget::isEmpty() const
 {
     return count() == 0;
 }
+
+#include "moc_customlogwidget.cpp"
