@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -39,13 +39,20 @@ public:
     void addTitleLogEntry(const QString &log);
     void addEndLineLogEntry();
 
-    Q_REQUIRED_RESULT QString toHtml() const;
-    Q_REQUIRED_RESULT QString toPlainText() const;
-    Q_REQUIRED_RESULT bool isEmpty() const;
+    [[nodiscard]] QString toHtml() const;
+    [[nodiscard]] QString toPlainText() const;
+    [[nodiscard]] bool isEmpty() const;
 
 private:
-    enum ItemType { ItemLogType = Qt::UserRole + 1 };
+    enum ItemType {
+        ItemLogType = Qt::UserRole + 1,
+    };
 
-    enum LogType { Title = 0, Error, Info, EndLine };
+    enum LogType {
+        Title = 0,
+        Error,
+        Info,
+        EndLine,
+    };
 };
 }
