@@ -25,12 +25,12 @@ public:
 
     void setDefaultText(const QString &text);
 
-    Q_REQUIRED_RESULT bool showDefaultText() const;
+    [[nodiscard]] bool showDefaultText() const;
     void setShowDefaultText(bool b);
 
 private:
-    void generalPaletteChanged();
-    void generalFontChanged();
+    PIMCOMMON_NO_EXPORT void generalPaletteChanged();
+    PIMCOMMON_NO_EXPORT void generalFontChanged();
 
 protected:
     void paintEvent(QPaintEvent *event) override;
