@@ -27,12 +27,16 @@ public:
     explicit PurposeMenuWidget(QWidget *parentWidget, QObject *parent = nullptr);
     ~PurposeMenuWidget() override;
 
-    virtual QByteArray text() = 0;
-    QMenu *menu() const;
+    [[nodiscard]] virtual QByteArray text() = 0;
+    [[nodiscard]] QMenu *menu() const;
+
+Q_SIGNALS:
+    void shareError(const QString &message);
+    void shareSuccess(const QString &url);
 
 private:
-    void slotInitializeShareMenu();
-    void slotShareActionFinished(const QJsonObject &output, int error, const QString &message);
+    PIMCOMMON_NO_EXPORT void slotInitializeShareMenu();
+    PIMCOMMON_NO_EXPORT void slotShareActionFinished(const QJsonObject &output, int error, const QString &message);
     Purpose::Menu *mShareMenu = nullptr;
     QTemporaryFile *mTemporaryShareFile = nullptr;
     QWidget *const mParentWidget;
