@@ -33,14 +33,14 @@ public:
         RENAMEFILE_OVERWRITEALL = 4
     };
 
-    Q_REQUIRED_RESULT QUrl newName() const;
+    [[nodiscard]] QUrl newName() const;
 
 private:
-    void slotOverwritePressed();
-    void slotIgnorePressed();
-    void slotRenamePressed();
-    void slotApplyAllPressed();
-    void slotSuggestNewNamePressed();
+    PIMCOMMON_NO_EXPORT void slotOverwritePressed();
+    PIMCOMMON_NO_EXPORT void slotIgnorePressed();
+    PIMCOMMON_NO_EXPORT void slotRenamePressed();
+    PIMCOMMON_NO_EXPORT void slotApplyAllPressed();
+    PIMCOMMON_NO_EXPORT void slotSuggestNewNamePressed();
     //@cond PRIVATE
     class RenameFileDialogPrivate;
     std::unique_ptr<RenameFileDialogPrivate> const d;
