@@ -32,7 +32,7 @@ class PimCommon::SimpleStringListEditorPrivate
 public:
     SimpleStringListEditorPrivate() = default;
 
-    Q_REQUIRED_RESULT QList<QListWidgetItem *> selectedItems() const
+    [[nodiscard]] QList<QListWidgetItem *> selectedItems() const
     {
         QList<QListWidgetItem *> listWidgetItem;
         const int numberOfFilters = mListBox->count();
@@ -305,7 +305,8 @@ void SimpleStringListEditor::slotRemove()
     if (selectedItems.isEmpty()) {
         return;
     }
-    const int answer = KMessageBox::warningTwoActions(this, d->mRemoveDialogLabel, i18n("Remove"), KStandardGuiItem::remove(), KStandardGuiItem::cancel());
+    const int answer =
+        KMessageBox::warningTwoActions(this, d->mRemoveDialogLabel, i18nc("@title:window", "Remove"), KStandardGuiItem::remove(), KStandardGuiItem::cancel());
     if (answer == KMessageBox::ButtonCode::PrimaryAction) {
         for (QListWidgetItem *item : selectedItems) {
             delete d->mListBox->takeItem(d->mListBox->row(item));
@@ -495,3 +496,5 @@ QSize SimpleStringListEditor::sizeHint() const
     sh.setHeight(d->mButtonLayout->minimumSize().height());
     return sh;
 }
+
+#include "moc_simplestringlisteditor.cpp"
