@@ -5,32 +5,28 @@
 */
 
 #pragma once
-
+#include "pimcommonakonadi_private_export.h"
 #include <QStringList>
 
 namespace PimCommon
 {
 class BalooCompletionEmail;
-class AddresseeLineEditBaloo
+class PIMCOMMONAKONADI_TESTS_EXPORT AddresseeLineEditBaloo
 {
 public:
     AddresseeLineEditBaloo();
     ~AddresseeLineEditBaloo();
 
-    Q_REQUIRED_RESULT int balooCompletionSource() const;
+    [[nodiscard]] int balooCompletionSource() const;
     void setBalooCompletionSource(int value);
-
-    Q_REQUIRED_RESULT QStringList balooBlackList() const;
-    Q_REQUIRED_RESULT QStringList domainExcludeList() const;
-
     void loadBalooBlackList();
-    Q_REQUIRED_RESULT QStringList cleanupEmailList(const QStringList &inputList);
+    [[nodiscard]] QStringList cleanupEmailList(const QStringList &inputList);
+
+    [[nodiscard]] QStringList balooBlackList() const;
+    [[nodiscard]] QStringList domainExcludeList() const;
 
 private:
     PimCommon::BalooCompletionEmail *const mBalooCompletionEmail;
-    QStringList mBalooBlackList;
-    QStringList mDomainExcludeList;
-
     int mBalooCompletionSource = 0;
 };
 }
