@@ -8,41 +8,27 @@
 #include "baloocompletionemail.h"
 #include <KEmailAddress>
 #include <QMap>
+#include <QRegularExpression>
 
 using namespace PimCommon;
 
 BalooCompletionEmail::BalooCompletionEmail() = default;
-
-void BalooCompletionEmail::setEmailList(const QStringList &lst)
-{
-    mListEmail = lst;
-}
-
-void BalooCompletionEmail::setExcludeDomain(const QStringList &lst)
-{
-    mExcludeDomain = lst;
-}
-
-void BalooCompletionEmail::setBlackList(const QStringList &lst)
-{
-    mBlackList = lst;
-}
-
+QList<QRegularExpression> BalooCompletionEmail::mExcludeEmailsRegularExpressions = {};
 QStringList BalooCompletionEmail::cleanupEmailList()
 {
-    if (mListEmail.isEmpty()) {
-        return mListEmail;
+    if (mBalooCompletionEmailInfo.mListEmail.isEmpty()) {
+        return {};
     }
     QMap<QString, QString> hashEmail;
-    for (QString email : std::as_const(mListEmail)) {
-        if (!mBlackList.contains(email)) {
+    for (QString email : std::as_const(mBalooCompletionEmailInfo.mListEmail)) {
+        if (!mBalooCompletionEmailInfo.mBlackList.contains(email)) {
             QString address;
             email = stripEmail(email, address);
             if (address.isEmpty()) {
                 address = email;
             }
             bool excludeMail = false;
-            for (const QString &excludeDomain : std::as_const(mExcludeDomain)) {
+            for (const QString &excludeDomain : std::as_const(mBalooCompletionEmailInfo.mExcludeDomains)) {
                 if (!excludeDomain.isEmpty()) {
                     if (address.endsWith(excludeDomain)) {
                         excludeMail = true;
@@ -50,6 +36,15 @@ QStringList BalooCompletionEmail::cleanupEmailList()
                     }
                 }
             }
+            if (!excludeMail) {
+                for (const QRegularExpression &excludeEmailRegularExpression : std::as_const(mExcludeEmailsRegularExpressions)) {
+                    if (address.contains(excludeEmailRegularExpression)) {
+                        excludeMail = true;
+                        continue;
+                    }
+                }
+            }
+
             const QString addressLower = address.toLower();
             if (!excludeMail && !hashEmail.contains(addressLower)) {
                 hashEmail.insert(addressLower, email);
@@ -90,3 +85,20 @@ QString BalooCompletionEmail::stripEmail(const QString &email, QString &address)
         return email;
     }
 }
+
+BalooCompletionEmail::BalooCompletionEmailInfo BalooCompletionEmail::balooCompletionEmailInfo() const
+{
+    return mBalooCompletionEmailInfo;
+}
+
+void BalooCompletionEmail::setBalooCompletionEmailInfo(const BalooCompletionEmailInfo &newBalooCompletionEmailInfo)
+{
+    mBalooCompletionEmailInfo = newBalooCompletionEmailInfo;
+    mExcludeEmailsRegularExpressions.clear();
+    for (const auto &str : std::as_const(mBalooCompletionEmailInfo.mExcludeEmailsRegularExpressions)) {
+        const QRegularExpression exp(str);
+        if (exp.isValid()) {
+            mExcludeEmailsRegularExpressions.append(exp);
+        }
+    }
+}
