@@ -6,7 +6,7 @@
 */
 
 #include "completionconfiguredialogtest.h"
-#include "../completionconfiguredialog/completionconfiguredialog.h"
+#include "addressline/completionconfiguredialog/completionconfiguredialog.h"
 #include <QDialogButtonBox>
 #include <QStandardPaths>
 #include <QTabWidget>
@@ -30,6 +30,7 @@ void CompletionConfigureDialogTest::shouldHaveDefaultValue()
 
     auto buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
     QVERIFY(buttonBox);
+    QCOMPARE(buttonBox->standardButtons(), QDialogButtonBox::StandardButtons{QDialogButtonBox::Ok | QDialogButtonBox::Apply | QDialogButtonBox::Cancel});
 
     auto tabWidget = dlg.findChild<QTabWidget *>(QStringLiteral("tabwidget"));
     QVERIFY(tabWidget);
@@ -43,3 +44,5 @@ void CompletionConfigureDialogTest::shouldHaveDefaultValue()
 }
 
 QTEST_MAIN(CompletionConfigureDialogTest)
+
+#include "moc_completionconfiguredialogtest.cpp"
