@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -13,14 +13,14 @@ BlackListBalooEmailSearchJobTest::BlackListBalooEmailSearchJobTest(QObject *pare
 {
 }
 
-BlackListBalooEmailSearchJobTest::~BlackListBalooEmailSearchJobTest()
-{
-}
+BlackListBalooEmailSearchJobTest::~BlackListBalooEmailSearchJobTest() = default;
 
 void BlackListBalooEmailSearchJobTest::shouldNotSearchWhenTextIsEmpty()
 {
-    auto *job = new PimCommon::BlackListBalooEmailSearchJob;
+    auto job = new PimCommon::BlackListBalooEmailSearchJob;
     QVERIFY(!job->start());
 }
 
 QTEST_MAIN(BlackListBalooEmailSearchJobTest)
+
+#include "moc_blacklistbalooemailsearchjobtest.cpp"
