@@ -11,7 +11,7 @@
 
 #include <QDialog>
 class KConfig;
-namespace KLDAP
+namespace KLDAPWidgets
 {
 class LdapClientSearch;
 }
@@ -31,15 +31,16 @@ public:
 
     void load();
     void setEmailBlackList(const QStringList &lst);
-    void setLdapClientSearch(KLDAP::LdapClientSearch *ldapSearch);
+    void setLdapClientSearch(KLDAPWidgets::LdapClientSearch *ldapSearch);
     void setRecentAddresses(const QStringList &lst);
-    Q_REQUIRED_RESULT bool recentAddressWasChanged() const;
+    [[nodiscard]] bool recentAddressWasChanged() const;
     void storeAddresses(KConfig *config);
 
 private:
-    void slotSave();
-    void readConfig();
-    void writeConfig();
+    PIMCOMMONAKONADI_NO_EXPORT void slotSaveAndClose();
+    PIMCOMMONAKONADI_NO_EXPORT void slotSave();
+    PIMCOMMONAKONADI_NO_EXPORT void readConfig();
+    PIMCOMMONAKONADI_NO_EXPORT void writeConfig();
     std::unique_ptr<CompletionConfigureDialogPrivate> const d;
 };
 }
