@@ -236,7 +236,7 @@ CompletionOrderWidget::CompletionOrderWidget(QWidget *parent)
     pageHBoxLayout->setContentsMargins({});
     hbox->addWidget(page);
     mListView = new QTreeWidget(page);
-    mListView->setObjectName(QStringLiteral("listview"));
+    mListView->setObjectName(QLatin1StringView("listview"));
 
     pageHBoxLayout->addWidget(mListView);
     mListView->setColumnCount(1);
@@ -253,7 +253,7 @@ CompletionOrderWidget::CompletionOrderWidget(QWidget *parent)
     mUpButton = new QPushButton(upDownBox);
     upDownBoxVBoxLayout->addWidget(mUpButton);
     mUpButton->setAutoRepeat(true);
-    mUpButton->setObjectName(QStringLiteral("mUpButton"));
+    mUpButton->setObjectName(QLatin1StringView("mUpButton"));
     mUpButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
     mUpButton->setEnabled(false); // b/c no item is selected yet
     mUpButton->setToolTip(i18n("Move Up"));
@@ -262,7 +262,7 @@ CompletionOrderWidget::CompletionOrderWidget(QWidget *parent)
     mDownButton = new QPushButton(upDownBox);
     upDownBoxVBoxLayout->addWidget(mDownButton);
     mDownButton->setAutoRepeat(true);
-    mDownButton->setObjectName(QStringLiteral("mDownButton"));
+    mDownButton->setObjectName(QLatin1StringView("mDownButton"));
     mDownButton->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
     mDownButton->setEnabled(false); // b/c no item is selected yet
     mDownButton->setToolTip(i18n("Move Down"));
