@@ -1,13 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SELECTMULTICOLLECTIONDIALOG_H
-#define SELECTMULTICOLLECTIONDIALOG_H
+#pragma once
 #include "pimcommonakonadi_export.h"
-#include <Collection>
+#include <Akonadi/Collection>
 #include <QDialog>
 
 namespace PimCommon
@@ -25,14 +24,13 @@ public:
     explicit SelectMultiCollectionDialog(const QString &mimetype, QWidget *parent = nullptr);
     ~SelectMultiCollectionDialog() override;
 
-    Q_REQUIRED_RESULT QVector<Akonadi::Collection> selectedCollection() const;
+    [[nodiscard]] QList<Akonadi::Collection> selectedCollection() const;
 
 private:
-    void initialize(const QString &mimetype, const QList<Akonadi::Collection::Id> &selectedCollection = QList<Akonadi::Collection::Id>());
-    void writeConfig();
-    void readConfig();
-    SelectMultiCollectionDialogPrivate *const d;
+    PIMCOMMONAKONADI_NO_EXPORT void initialize(const QString &mimetype,
+                                               const QList<Akonadi::Collection::Id> &selectedCollection = QList<Akonadi::Collection::Id>());
+    PIMCOMMONAKONADI_NO_EXPORT void writeConfig();
+    PIMCOMMONAKONADI_NO_EXPORT void readConfig();
+    std::unique_ptr<SelectMultiCollectionDialogPrivate> const d;
 };
 }
-
-#endif // SELECTMULTICOLLECTIONDIALOG_H
