@@ -1,16 +1,15 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef GENERICPLUGININTERFACE_H
-#define GENERICPLUGININTERFACE_H
+#pragma once
 
 #include "pimcommonakonadi_export.h"
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 #include <PimCommon/AbstractGenericPluginInterface>
-#include <QObject>
+
 namespace PimCommon
 {
 class GenericPluginInterfacePrivate;
@@ -25,13 +24,19 @@ public:
     explicit GenericPluginInterface(QObject *parent = nullptr);
     ~GenericPluginInterface() override;
 
-    enum RequireType { None = 0, CurrentItems = 1, Items = 2, CurrentCollection = 3, Collections = 4 };
+    enum RequireType {
+        None = 0,
+        CurrentItems = 1,
+        Items = 2,
+        CurrentCollection = 3,
+        Collections = 4,
+    };
     Q_ENUM(RequireType)
     Q_DECLARE_FLAGS(RequireTypes, RequireType)
 
-    void setActionTypes(const QVector<ActionType> &type);
+    void setActionTypes(const QList<ActionType> &type);
     void addActionType(ActionType type);
-    Q_REQUIRED_RESULT QVector<ActionType> actionTypes() const;
+    [[nodiscard]] QList<ActionType> actionTypes() const;
 
     virtual void setCurrentItems(const Akonadi::Item::List &items);
     virtual void setItems(const Akonadi::Item::List &items);
@@ -43,8 +48,7 @@ public:
     virtual void updateActions(int numberOfSelectedItems, int numberOfSelectedCollections);
 
 private:
-    GenericPluginInterfacePrivate *const d;
+    std::unique_ptr<GenericPluginInterfacePrivate> const d;
 };
 }
-Q_DECLARE_TYPEINFO(PimCommon::ActionType, Q_MOVABLE_TYPE);
-#endif // GENERICPLUGININTERFACE_H
+Q_DECLARE_TYPEINFO(PimCommon::ActionType, Q_RELOCATABLE_TYPE);
